@@ -158,7 +158,7 @@ class _vcf_metadata_parser(object):
         # Removing initial hash marks and final equal sign
         key = items[0][2:-1]
         hashItems = items[1].split(',')
-        val = dict(item.split("=") for item in hashItems)
+        val = OrderedDict(item.split("=") for item in hashItems)
         return key, val
 
     def read_meta(self, meta_string):
@@ -554,7 +554,12 @@ class Writer(object):
             if key in SINGULAR_METADATA:
                 vals = [vals]
             for val in vals:
-                stream.write('##{0}={1}\n'.format(key, val))
+                if isinstance(val, dict):
+                    values = ','.join('{0}={1}'.format(key, value)
+                                      for key, value in val.items())
+                    stream.write('##{0}=<{1}>\n'.format(key, values))
+                else:
+                    stream.write('##{0}={1}\n'.format(key, val))
         for line in template.infos.itervalues():
             stream.write(four.format(key="INFO", *line, num=_num(line.num)))
         for line in template.formats.itervalues():
