@@ -218,7 +218,11 @@ class TestGatkOutputWriter(unittest.TestCase):
         for record in records:
             writer.write_record(record)
         out.seek(0)
-        print (out.getvalue())
+        out_str = out.getvalue()
+        for line in out_str.split("\n"):
+            if line.startswith("##contig"):
+                assert line.startswith('##contig=<'), "Found dictionary in contig line: {0}".format(line)
+        print (out_str)
         reader2 = vcf.Reader(out)
 
         self.assertEquals(reader.samples, reader2.samples)
@@ -253,6 +257,27 @@ class TestBcfToolsOutputWriter(unittest.TestCase):
             self.assertEquals(l.samples, r.samples)
 
 
+class TestWriterDictionaryMeta(unittest.TestCase):
+
+    def testWrite(self):
+
+        reader = vcf.Reader(fh('example-4.1-bnd.vcf'))
+        out = StringIO()
+        writer = vcf.Writer(out, reader)
+
+        records = list(reader)
+
+        for record in records:
+            writer.write_record(record)
+        out.seek(0)
+        out_str = out.getvalue()
+        for line in out_str.split("\n"):
+            if line.startswith("##PEDIGREE"):
+                self.assertEquals(line, '##PEDIGREE=<Derived="Tumor",Original="Germline">')
+            if line.startswith("##SAMPLE"):
+                assert line.startswith('##SAMPLE=<'), "Found dictionary in meta line: {0}".format(line)
+
+
 class TestRecord(unittest.TestCase):
 
     def test_num_calls(self):
@@ -785,6 +810,7 @@ suite.addTests(unittest.TestLoader().loadTestsFromTestCase(TestSamtoolsOutput))
 suite.addTests(unittest.TestLoader().loadTestsFromTestCase(TestBcfToolsOutput))
 suite.addTests(unittest.TestLoader().loadTestsFromTestCase(TestGatkOutputWriter))
 suite.addTests(unittest.TestLoader().loadTestsFromTestCase(TestBcfToolsOutputWriter))
+suite.addTests(unittest.TestLoader().loadTestsFromTestCase(TestWriterDictionaryMeta))
 suite.addTests(unittest.TestLoader().loadTestsFromTestCase(TestTabix))
 suite.addTests(unittest.TestLoader().loadTestsFromTestCase(TestOpenMethods))
 suite.addTests(unittest.TestLoader().loadTestsFromTestCase(TestFilter))
